/*
 * libisdn features/version
 *
 */
#ifndef __LIBISDN_FEATURES_H__
#define __LIBISDN_FEATURES_H__

/**
 * version convert macro
 *
 * @code
 * // Example
 * #if LIBISDN_VERSION_INT >= LIBISDN_VERSION(1,0,0)
 *    ... do something that requires at least libisdn-1.0.0 ...
 * #endif
 * @endcode
 */
#define LIBISDN_VERSION(maj, min, patch)	\
	(((maj) << 24) | ((min) << 16) | ((patch) << 8) | 0U)

/**
 * feature check macro
 *
 * @code
 * // Example
 * #if LIBISDN_FEATURE(LUA)
 *    ... do something that requires lua in libisdn ...
 * #endif
 * @endcode
 */
#define LIBISDN_FEATURE(x)	\
	(defined(LIBISDN_FEATURE_##x) && (LIBISDN_FEATURE_##x == 1))

/**
 * platform macro
 *
 * @code
 * // Example
 * #if LIBISDN_PLATFORM(WIN32)
 *    ... do something that only works on WIN32 ...
 * #endif
 * @endcode
 */
#define LIBISDN_PLATFORM(x)	\
	(defined(LIBISDN_PLATFORM_##x) && (LIBISDN_PLATFORM_##x == 1))

/**
 * platform macro
 *
 * @code
 * // Example
 * #if LIBISDN_COMPILER(GNU)
 *    ... do something that only works on GNU (gcc) ...
 * #endif
 * @endcode
 * @internal
 */
#define LIBISDN_COMPILER(x)	\
	(defined(LIBISDN_COMPILER_##x) && (LIBISDN_COMPILER_##x == 1))

/*********************************************************************************
 * Do not touch anything below (autogenerated values)
 *********************************************************************************/

/* version components */
#define LIBISDN_VERSION_MAJOR	0
#define LIBISDN_VERSION_MINOR	0
#define LIBISDN_VERSION_PATCH	1

/* platform we run on */
#define LIBISDN_PLATFORM_LINUX	1
#define LIBISDN_PLATFORM_STRING			"LINUX"

/* special shortcut for windows (and maybe others) */
#if LIBISDN_PLATFORM(WIN32) || LIBISDN_PLATFORM(WIN64)
#define LIBISDN_PLATFORM_WINDOWS	1
#endif

/* compiler (vendor) we were built from */
#define LIBISDN_COMPILER_GNU	1
#define LIBISDN_COMPILER_STRING			"GNU"

/* version, integer and string value */
#define LIBISDN_VERSION_INT	\
	LIBISDN_VERSION(LIBISDN_VERSION_MAJOR, LIBISDN_VERSION_MINOR, LIBISDN_VERSION_PATCH)

#define LIBISDN_VERSION_STRING	\
	"0.0.1"

/* feature flags */
#define LIBISDN_FEATURE_API2	1

#endif /* __LIBISDN_FEATURES_H__ */
